toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final verb = kind == ConflictKind.writeWrite
      ? 'both write'
      : 'conflict (read/write) on';
  return 'Access conflict in schedule "${schedule.id}": ${a.id} and ${b.id} '
      '$verb $component without an ordering between them. Add an after/before '
      'edge, or confirm the access is safe.';
}