profiler property

SystemProfiler? profiler
final

The system profiler, or null when profiling is disabled. When enabled it is also inserted as a @Resource() so overlays/systems can read it.

Implementation

final SystemProfiler? profiler;