AppBuilder class abstract interface

Registers app systems and data.

Implementers
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCleanup(FutureOr<void> cleanup()) AppBuilder
Registers cleanup to run once when the app shuts down.
addEvent<T>({int? retainedUpdates}) AppBuilder
Registers an event channel for T.
addPlugin(Plugin plugin) AppBuilder
Builds plugin into this app if it has not already been added.
addState<S extends Object>(S initial) AppBuilder
Registers state S with initial.
addSystem(SystemDescriptor descriptor, {required ScheduleLabel schedule, List<SystemDescriptor> after, List<SystemDescriptor> before, RunCondition? runIf, SystemSet? inSet}) AppBuilder
Registers descriptor in schedule.
addSystemAdapter(SystemAdapter adapter, {required ScheduleLabel schedule, required SystemLabel label, List<SystemLabel> after, List<SystemLabel> before, List<SystemLabel> independentOf, RunCondition? runIf, SystemSet? inSet}) AppBuilder
Registers adapter in schedule.
addSystems(ScheduleLabel schedule, List<SystemDescriptor> descriptors, {RunCondition? runIf, SystemSet? inSet, bool chained = false}) AppBuilder

Available on AppBuilder, provided by the AppBuilderSystems extension

Registers descriptors in schedule.
configureSets(ScheduleLabel schedule, List<SystemSet> sets) AppBuilder
Orders sets within schedule.
insertResource<T extends Object>(T resource) AppBuilder
Inserts resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceResource<T extends Object>(T resource) AppBuilder
Replaces or inserts resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited