remove<T> method
Queues removing the component of type T from entity.
Implementation
void remove<T>(Entity entity) {
_push(_opRemove, entity, null, T);
}
Queues removing the component of type T from entity.
void remove<T>(Entity entity) {
_push(_opRemove, entity, null, T);
}