ComponentStore class abstract base

Implementers

Constructors

ComponentStore({int denseCapacity = 8, int sparseCapacity = 16})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
onAdded ↔ void Function(int entityIndex, Object? payload)?
getter/setter pair
onRemoved ↔ void Function(int entityIndex, Object? payload)?
getter/setter pair
revision int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bumpRevision() → void
clear() → void
clearPayload(int dense) → void
containsIndex(int entityIndex) bool
denseIndexOf(int entityIndex) int
entityIndexAt(int dense) int
growPayload(int newCapacity) → void
insertDynamic(int entityIndex, Object? value) → void
movePayload(int from, int to) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payloadAt(int dense) Object?
putSlot(int entityIndex) int
removeEntityIndex(int entityIndex) → void
removeSlot(int entityIndex) int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited