EntityCommands class final

Fluent deferred commands targeting one entity.

Constructors

EntityCommands(Commands _commands, Entity entity)

Properties

entity Entity
The entity these commands target.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

despawn() → void
Queues despawning entity.
insert<T>(T component) EntityCommands
Queues inserting component of type T onto entity.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove<T>() EntityCommands
Queues removing the component of type T from entity.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited