remove<T> method
Queues removing the component of type T from entity.
Implementation
EntityCommands remove<T>() {
_commands.remove<T>(entity);
return this;
}
Queues removing the component of type T from entity.
EntityCommands remove<T>() {
_commands.remove<T>(entity);
return this;
}