EntityDetailSnapshot class final

Component details for one entity.

Constructors

EntityDetailSnapshot({required int index, required int generation, required String? name, required List<String> lines, required bool stale})
const

Properties

generation int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
lines List<String>
One entry per component, in store-registration order.
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale bool
Whether the entity is no longer live.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited