retainedUpdates property
How many maintenance passes an unread event survives, or null for
unbounded retention.
Implementation
final int? retainedUpdates;
How many maintenance passes an unread event survives, or null for
unbounded retention.
final int? retainedUpdates;