InspectorSnapshot class final

A summary of one world.

Constructors

InspectorSnapshot({required int entityCount, required List<StoreSnapshot> stores, required List<EntitySnapshot> entities, required List<ResourceSnapshot> resources, required List<SystemSnapshot> systems, required List<EventChannelSnapshot> events})
const

Properties

entities List<EntitySnapshot>
One summary per live entity.
final
entityCount int
Live entities at collection time.
final
events List<EventChannelSnapshot>
Registered event channels, in registration order.
final
hashCode int
The hash code for this object.
no setterinherited
resources List<ResourceSnapshot>
Registered resources, in insertion order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stores List<StoreSnapshot>
Per-store dense counts, in store-registration order.
final
systems List<SystemSnapshot>
Collected system timings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited