ObjectComponentStore<T> class final

Inheritance

Constructors

ObjectComponentStore({int denseCapacity = 8, int sparseCapacity = 16})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setterinherited
onAdded ↔ void Function(int entityIndex, Object? payload)?
getter/setter pairinherited
onRemoved ↔ void Function(int entityIndex, Object? payload)?
getter/setter pairinherited
revision int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bumpRevision() → void
inherited
clear() → void
inherited
clearPayload(int dense) → void
override
containsIndex(int entityIndex) bool
inherited
denseIndexOf(int entityIndex) int
inherited
entityIndexAt(int dense) int
inherited
growPayload(int newCapacity) → void
override
insert(int entityIndex, T value) → void
insertDynamic(int entityIndex, Object? value) → void
override
movePayload(int from, int to) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payloadAt(int dense) Object?
override
putSlot(int entityIndex) int
inherited
removeEntityIndex(int entityIndex) → void
inherited
removeSlot(int entityIndex) int
inherited
toString() String
A string representation of this object.
inherited
valueAt(int dense) → T
valueOf(int entityIndex) → T?

Operators

operator ==(Object other) bool
The equality operator.
inherited