OptionalSingle<A> class final

Constructors

OptionalSingle(Query1<A> _query)

Properties

entityOrNull Entity?
no setter
hashCode int
The hash code for this object.
no setterinherited
isPresent bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueOrNull → A?
no setter

Methods

beginRun() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited