Plugin class abstract base

Registers one app feature.

Constructors

Plugin()
const

Properties

dependencies List<Type>
Plugins that must be added first.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(AppBuilder app) → void
Registers this plugin's systems, events and resources on app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited