Query1<A> class
final
Constructors
-
Query1(World _world, ObjectComponentStore<
A> _a, List<ComponentStore> _withStores, List<ComponentStore> _withoutStores)
Properties
- debugLabel → String
-
no setter
- debugRowEstimate → int
-
no setter
- driverLength → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
any(
Query1UntilCallback< A> predicate) → bool -
components(
Entity entity) → (A)? -
count(
) → int -
each(
Query1Callback< A> callback) → void -
eachUntil(
Query1UntilCallback< A> callback) → void -
firstWhere(
Query1UntilCallback< A> predicate) → (Entity, A)? -
get(
Entity entity) → A? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
single(
) → (Entity, A) -
singleOrNull(
) → (Entity, A)? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited