Query2<A, B> class final

Constructors

Query2(World _world, ObjectComponentStore<A> _a, ObjectComponentStore<B> _b, List<ComponentStore> _withStores, List<ComponentStore> _withoutStores)

Properties

debugLabel String
no setter
debugRowEstimate int
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

any(Query2UntilCallback<A, B> predicate) bool
components(Entity entity) → (A, B)?
count() int
each(Query2Callback<A, B> callback) → void
eachUntil(Query2UntilCallback<A, B> callback) → void
firstWhere(Query2UntilCallback<A, B> predicate) → (Entity, A, B)?
get(Entity entity, Query2Callback<A, B> found) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
single() → (Entity, A, B)
singleOrNull() → (Entity, A, B)?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited