Query3<A, B, C> class final

Constructors

Query3(World _world, ObjectComponentStore<A> _a, ObjectComponentStore<B> _b, ObjectComponentStore<C> _c, List<ComponentStore> _withStores, List<ComponentStore> _withoutStores)

Properties

debugLabel String
no setter
debugRowEstimate int
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

any(Query3UntilCallback<A, B, C> predicate) bool
components(Entity entity) → (A, B, C)?
count() int
each(Query3Callback<A, B, C> callback) → void
eachUntil(Query3UntilCallback<A, B, C> callback) → void
firstWhere(Query3UntilCallback<A, B, C> predicate) → (Entity, A, B, C)?
get(Entity entity, Query3Callback<A, B, C> found) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
single() → (Entity, A, B, C)
singleOrNull() → (Entity, A, B, C)?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited