ResourceSnapshot class final

One resource: its type name and, when the instance overrides Object.toString (same default-Instance of filter as debugDescribe), that rendering.

Constructors

ResourceSnapshot({required String type, required String? value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited