SceneDashBundle class abstract interface

Inserts a group of components.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

insertInto(World world, Entity entity) → void
Inserts all of this bundle's components onto entity in world. Called by the command buffer at a safe boundary, so it may register stores and mutate component storage directly.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited