insertInto abstract method

void insertInto(
  1. World world,
  2. Entity entity
)

Inserts all of this bundle's components onto entity in world. Called by the command buffer at a safe boundary, so it may register stores and mutate component storage directly.

Implementation

void insertInto(World world, Entity entity);