SlowSystemEvent class final
Emitted when a system's run exceeds the configured slow-system threshold.
Constructors
- SlowSystemEvent({required SystemTiming timing, required Duration elapsed, required int frame})
-
const
Properties
- elapsed → Duration
-
How long this run took.
final
- frame → int
-
The frame number the slow run happened on.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timing → SystemTiming
-
The timing record for the system that ran slowly.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited