SnapshotCollector class final

Collects InspectorSnapshot data on demand.

Constructors

SnapshotCollector(World world)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
world World
final

Methods

collect() InspectorSnapshot
Collects the summary snapshot: counts, entity summaries (type names only), resources, profiled timings, event channels.
describeEntity(int index, int generation) EntityDetailSnapshot
Collects details for one entity.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited