StateScheduleLabel class sealed

A schedule that belongs to a state value's enter/exit lifecycle.

Unlike plain schedules, state schedules are created on demand when a system is registered into them, and are run by the transition machinery rather than the frame driver.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier string.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
The state value this schedule is attached to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited