SystemDescriptor class final

Describes a schedulable system.

Constructors

SystemDescriptor(SystemRef ref, SystemAdapter buildAdapter())
const

Properties

buildAdapter SystemAdapter Function()
Builds a fresh adapter for this system. Called once when the descriptor is registered into a schedule.
final
hashCode int
The hash code for this object.
no setterinherited
ref SystemRef
This system's stable identity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited