buildAdapter property
Builds a fresh adapter for this system. Called once when the descriptor is registered into a schedule.
Implementation
final SystemAdapter Function() buildAdapter;
Builds a fresh adapter for this system. Called once when the descriptor is registered into a schedule.
final SystemAdapter Function() buildAdapter;