SystemLabel class final

A stable identifier for a single registered system.

System labels are used to declare ordering between systems via before and after edges, and to detect duplicate registrations.

Constructors

SystemLabel(String id)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
The unique identifier string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override