timingOf method
The timing record for system in schedule, or null if that pair has not
run yet.
Implementation
SystemTiming? timingOf(SystemLabel system, ScheduleLabel schedule) =>
_timings[system]?[schedule];
The timing record for system in schedule, or null if that pair has not
run yet.
SystemTiming? timingOf(SystemLabel system, ScheduleLabel schedule) =>
_timings[system]?[schedule];