SystemRef class final

Stable identity for a system.

Constructors

SystemRef(String library, String name, {String? debugName})
const

Properties

debugName String?
Optional name for diagnostics.
final
hashCode int
The hash code for this object.
no setteroverride
label SystemLabel
Scheduling key for this identity.
no setter
library String
The URI of the library that declares the system, e.g. package:scene_game/player/player.dart.
final
name String
The declared name of the system (class or function), e.g. MovePlayerSystem.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override