library property
The URI of the library that declares the system, e.g.
package:scene_game/player/player.dart.
Implementation
final String library;
The URI of the library that declares the system, e.g.
package:scene_game/player/player.dart.
final String library;