SystemSnapshot class final

Timing for one system and schedule.

Constructors

SystemSnapshot({required String label, required String schedule, required double lastMs, required double averageMs})
const

Properties

averageMs double
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
lastMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited