lastFrame property
int
get
lastFrame
The frame number of the most recent run (-1 until first run).
Implementation
int get lastFrame => _lastFrame;
The frame number of the most recent run (-1 until first run).
int get lastFrame => _lastFrame;