latestMicros property
int
get
latestMicros
Time spent in the most recent run, in microseconds.
Implementation
int get latestMicros => _latestMicros;
Time spent in the most recent run, in microseconds.
int get latestMicros => _latestMicros;