AccessConflict class final
A detected access conflict between two systems in the same schedule that have no ordering relationship and touch the same component in a conflicting way.
Constructors
- AccessConflict({required ScheduleLabel schedule, required SystemLabel a, required SystemLabel b, required Type component, required ConflictKind kind})
-
const
Properties
- a → SystemLabel
-
The two conflicting systems (order is not significant).
final
- b → SystemLabel
-
final
- component → Type
-
The component both systems touch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ConflictKind
-
Whether this is a write/write or read/write hazard.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule → ScheduleLabel
-
The schedule both systems belong to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited