Commands class final
Queues structural world changes.
Properties
Methods
-
apply(
) → void - Applies and clears all pending commands. Must not be called while a query is iterating.
-
despawn(
Entity entity) → void -
Queues despawning
entity. -
entity(
Entity entity) → EntityCommands -
Returns a fluent command handle targeting
entity. -
insert<
T> (Entity entity, T component) → void -
Queues inserting
componentof typeTontoentity. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove<
T> (Entity entity) → void -
Queues removing the component of type
Tfromentity. -
removeByType(
Type componentType, Entity entity) → void -
Queues removal using a runtime
componentType. -
spawn(
[SceneDashBundle? bundle]) → EntityCommands -
Reserves an entity and queues
bundle. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited