EntityQuery class final

Constructors

EntityQuery(World _world, List<ComponentStore> _withStores, List<ComponentStore> _withoutStores)

Properties

debugLabel String
no setter
debugRowEstimate int
no setter
firstOrNull Entity?
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

any(EntityQueryUntilCallback predicate) bool
contains(Entity entity) bool
count() int
each(EntityQueryCallback callback) → void
eachUntil(EntityQueryUntilCallback callback) → void
firstWhere(EntityQueryUntilCallback predicate) Entity?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited