reader method

EventReader<T> reader()

Creates a reader positioned at the current end (it will only observe events sent after this call).

Implementation

EventReader<T> reader() {
  final reader = EventReader<T>._(this).._cursor = _end;
  _readers.add(reader);
  return reader;
}