Query4<A, B, C, D> class
final
Constructors
-
Query4(World _world, ObjectComponentStore<
A> _a, ObjectComponentStore<B> _b, ObjectComponentStore<C> _c, ObjectComponentStore<D> _d, List<ComponentStore> _withStores, List<ComponentStore> _withoutStores)
Properties
- debugLabel → String
-
no setter
- debugRowEstimate → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
any(
Query4UntilCallback< A, B, C, D> predicate) → bool -
components(
Entity entity) → (A, B, C, D)? -
count(
) → int -
each(
Query4Callback< A, B, C, D> callback) → void -
eachUntil(
Query4UntilCallback< A, B, C, D> callback) → void -
firstWhere(
Query4UntilCallback< A, B, C, D> predicate) → (Entity, A, B, C, D)? -
get(
Entity entity, Query4Callback< A, B, C, D> found) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
single(
) → (Entity, A, B, C, D) -
singleOrNull(
) → (Entity, A, B, C, D)? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited