SystemAccess class final
Component types read and written by a system.
Constructors
-
SystemAccess({Set<
Type> reads = const <Type>{}, Set<Type> writes = const <Type>{}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
reads
→ Set<
Type> -
Component types the system reads (queried but not in
writes).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writes
→ Set<
Type> -
Component types the system declares it writes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const SystemAccess
- Access that touches nothing.