SystemLabel class final
A stable identifier for a single registered system.
System labels are used to declare ordering between systems via before and
after edges, and to detect duplicate registrations.
Constructors
- SystemLabel(String id)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override